Improve this Doc View Source

The `ngDblclick` directive allows you to specify custom behavior on a dblclick event.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as element:

      <ng-dblclick
        ng-dblclick="expression">
      ...
      </ng-dblclick>

- as attribute:

      <ANY
        ng-dblclick="expression">
      ...
      </ANY>

### Arguments

Param | Type | Details
--- | --- | ---
ngDblclick | expression | Expression to evaluate upon a dblclick. (The Event object is available as `$event`)

## Examples

    <button ng-dblclick="count = count + 1" ng-init="count=0">
      Increment (on double click)
    </button>
    count: {{count}}